@@ -9,7 +9,7 @@ from markdown_predictions.parse_data import LoadSalesData
 
 PRICE_COLS = ["price_PRE", "price_POST"]
 TARGET_SALES = ["quantity_sold_POST", "quantity_sold_sub1_POST"]
-DATE_COLS = ["first_week_sale_POST"]
+DATE_COLS = ["first_week_sale_PRE"]
 
 
 class PreProcessor:
@@ -27,6 +27,7 @@ class PreProcessor:
         """ Drop all rows with a '-' or 'nan' within them """
         self.df = self.df[~(self.df == '-').any(axis=1)]
         self.df = self.df[~(self.df == 'nan').any(axis=1)]
+        self.df = self.df[~(self.df == 'Inconnu').any(axis=1)]
 
     def replace_decimal_in_price_cols(self):
         """ Replace the comma with a decimal point in price columns """
@@ -55,6 +56,7 @@ class PreProcessor:
     def add_2week_sales(self):
         """ Add sales target """
         self.df["two_week_sales"] = self.df[TARGET_SALES].sum(axis=1)
+        self.df = self.df[self.df["two_week_sales"] >= 0]
         self.df.drop(TARGET_SALES, axis=1, inplace=True)
 
     def parse_dates(self):
@@ -70,11 +72,25 @@ class PreProcessor:
         self.drop_row_with_missing_entries()
         self.replace_decimal_in_price_cols()
         self.make_columns_numeric()
+        self.parse_dates()
         if train_set:
             self.add_2week_sales()
-            self.parse_dates()
 
 
+def outlier_scan(df, cols, threshold=0.1):
+    """ Detect numeric outliers based upon quantile threshold """
+    liers = set([])
+    index = df.index.copy()
+    for col in cols:
+        Q1 = df[[col]].quantile(threshold)[0]
+        Q3 = df[[col]].quantile(1-threshold)[0]
+        IQR = Q3 - Q1
+        low_liers = df[[col]][df[col] < Q1 - 1.5 * IQR].index.tolist()
+        high_liers = df[[col]][df[col] > Q3 + 1.5 * IQR].index.tolist()
+        liers.update(low_liers)
+        liers.update(high_liers)
+    return sorted(list(liers))
+
 if __name__ == "__main__":
     # Load in the data locally into a single dataframe
     loaded_data = LoadSalesData.load_in_files("raw_data")
